package com.goldenwater.slaj.sins.mapper;

import java.util.List;
import org.apache.ibatis.annotations.Mapper;
import com.goldenwater.slaj.sins.domain.RelSinsToOrg;

@Mapper
public interface RelSinsToOrgMapper {
    RelSinsToOrg selectRelSinsToOrgByGuid(String guid);
    List<RelSinsToOrg> selectRelSinsToOrgList(RelSinsToOrg entity);
    int insertRelSinsToOrg(RelSinsToOrg entity);
    int updateRelSinsToOrg(RelSinsToOrg entity);
    int deleteRelSinsToOrgByGuid(String guid);
    int deleteRelSinsToOrgByGuids(String[] guids);
}
